Implementation of 1-Wire with added Alarm Search Functionality

Dependents:   Max32630_One_Wire_Interface

Revision:
75:8b627804927c
Parent:
73:2cecc1372acc
Child:
82:c11090a32471
diff -r 23be10c32fa3 -r 8b627804927c RomId.h
--- a/RomId.h	Fri May 13 07:48:35 2016 -0500
+++ b/RomId.h	Fri May 13 14:52:50 2016 -0500
@@ -51,14 +51,14 @@
       /// @param crc8 Beginning state of the CRC generator.
       /// @param data Data to pass though the CRC generator.
       /// @returns The calculated CRC8.
-      static uint8_t calculateCRC8(uint8_t crc8, uint8_t data);
+      static uint8_t calculateCrc8(uint8_t crc8, uint8_t data);
       
       /// Perform a CRC8 calculation with variable length data.
       /// @param[in] data Data array to pass through the CRC generator.
       /// @param data_len Length of the data array to process.
       /// @param crc Beginning state of the CRC generator.
       /// @returns The calculated CRC8.
-      static uint8_t calculateCRC8(const uint8_t * data, size_t data_len, uint8_t crc = 0);
+      static uint8_t calculateCrc8(const uint8_t * data, size_t dataLen, uint8_t crc = 0);
 
   private:
       static const size_t familyCodeIdx = 0;
@@ -136,13 +136,13 @@
       /// @returns True if the CRC8 is valid.
       bool crc8Valid() const
       {
-          return (calculateCRC8(m_romId, (byteLen - 1), 0x00) == crc8());
+          return (calculateCrc8(m_romId, (byteLen - 1), 0x00) == crc8());
       }
       
       /// Calculate and set the CRC8 for the ROM ID.
       void setValidCrc8()
       {
-          setCrc8(calculateCRC8(m_romId, (byteLen - 1), 0x00));
+          setCrc8(calculateCrc8(m_romId, (byteLen - 1), 0x00));
       }
 
       /// Check if the ROM ID is valid (Family Code and CRC8 are both valid).
@@ -51,14 +51,14 @@
       /// Perform a CRC8 calculation with variable length data.
       /// @param[in] data Data array to pass through the CRC generator.
-      /// @param data_len Length of the data array to process.
+      /// @param dataLen Length of the data array to process.
       /// @param crc Beginning state of the CRC generator.
       /// @returns The calculated CRC8.